Configuration
=============

.. currentmodule:: semra.pipeline

.. autoclass:: Configuration
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Configuration.model_computed_fields
      ~Configuration.model_config
      ~Configuration.model_fields

   .. rubric:: Methods Summary

   .. autosummary::

      ~Configuration.from_prefixes
      ~Configuration.get_mappings
      ~Configuration.infer_priority

   .. rubric:: Attributes Documentation

   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields

   .. rubric:: Methods Documentation

   .. automethod:: from_prefixes
   .. automethod:: get_mappings
   .. automethod:: infer_priority
